@@ -54,12 +54,15 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             logger.error(f'write to kafka channel "{self._config.topic}" failed, error: {exc}')
             return False
 
-    async def mark_notification_as_read_internal(self, user_id: int, source_ids: list[int]) -> None:
-        logger.debug(f'mark notification for user({user_id}) as read for sources: {source_ids}')
+    async def mark_notification_as_read_internal(
+        self, user_id: int, source_type: SourceTypes, source_ids: list[int]
+    ) -> None:
+        logger.debug(f'mark notification for user({user_id}) as read for sources({source_type}): {source_ids}')
         async with self._http_client.post(
             f'{self._config.url}/v1/mark_notification_as_read_internal',
             json={
                 'user_id': user_id,
+                'source_type': source_type,
                 'source_ids': source_ids,
             },
         ) as response:
